@@ -1,12 +1,13 @@
 """
-This module implements the FormRequest class which is a more covenient class
+This module implements the FormRequest class which is a more convenient class
 (than Request) to generate Requests based on form data.
 
 See documentation in docs/topics/request-response.rst
 """
 
-import urllib, urlparse
+from six.moves.urllib.parse import urljoin, urlencode
 import lxml.html
+import six
 from scrapy.http.request import Request
 from scrapy.utils.python import unicode_to_str
 
@@ -21,7 +22,7 @@ class FormRequest(Request):
         super(FormRequest, self).__init__(*args, **kwargs)
 
         if formdata:
-            items = formdata.iteritems() if isinstance(formdata, dict) else formdata
+            items = formdata.items() if isinstance(formdata, dict) else formdata
             querystr = _urlencode(items, self.encoding)
             if self.method == 'POST':
                 self.headers.setdefault('Content-Type', 'application/x-www-form-urlencoded')
@@ -39,16 +40,19 @@ class FormRequest(Request):
         method = kwargs.pop('method', form.method)
         return cls(url=url, method=method, formdata=formdata, **kwargs)
 
+
 def _get_form_url(form, url):
     if url is None:
         return form.action or form.base_url
-    return urlparse.urljoin(form.base_url, url)
+    return urljoin(form.base_url, url)
+
 
 def _urlencode(seq, enc):
     values = [(unicode_to_str(k, enc), unicode_to_str(v, enc))
               for k, vs in seq
               for v in (vs if hasattr(vs, '__iter__') else [vs])]
-    return urllib.urlencode(values, doseq=1)
+    return urlencode(values, doseq=1)
+
 
 def _get_form(response, formname, formnumber, formxpath):
     """Find the form element """
@@ -83,10 +87,11 @@ def _get_form(response, formname, formnumber, formxpath):
             form = forms[formnumber]
         except IndexError:
             raise IndexError("Form number %d not found in %s" %
-                                (formnumber, response))
+                             (formnumber, response))
         else:
             return form
 
+
 def _get_inputs(form, formdata, dont_click, clickdata, response):
     try:
         formdata = dict(formdata or ())
@@ -97,8 +102,8 @@ def _get_inputs(form, formdata, dont_click, clickdata, response):
                         '|descendant::select'
                         '|descendant::input[@type!="submit" and @type!="image" and @type!="reset"'
                         'and ((@type!="checkbox" and @type!="radio") or @checked)]')
-    values = [(k, u'' if v is None else v) \
-              for k, v in (_value(e) for e in inputs) \
+    values = [(k, u'' if v is None else v)
+              for k, v in (_value(e) for e in inputs)
               if k and k not in formdata]
 
     if not dont_click:
@@ -106,9 +111,10 @@ def _get_inputs(form, formdata, dont_click, clickdata, response):
         if clickable and clickable[0] not in formdata and not clickable[0] is None:
             values.append(clickable)
 
-    values.extend(formdata.iteritems())
+    values.extend(formdata.items())
     return values
 
+
 def _value(ele):
     n = ele.name
     v = ele.value
@@ -116,6 +122,7 @@ def _value(ele):
         return _select_value(ele, n, v)
     return n, v
 
+
 def _select_value(ele, n, v):
     multiple = ele.multiple
     if v is None and not multiple:
@@ -161,7 +168,7 @@ def _get_clickable(clickdata, form):
     # We didn't find it, so now we build an XPath expression out of the other
     # arguments, because they can be used as such
     xpath = u'.//*' + \
-            u''.join(u'[@%s="%s"]' % c for c in clickdata.iteritems())
+            u''.join(u'[@%s="%s"]' % c for c in six.iteritems(clickdata))
     el = form.xpath(xpath)
     if len(el) == 1:
         return (el[0].name, el[0].value)
