@@ -20,15 +20,17 @@ def assert_aws_environ():
     if 'AWS_ACCESS_KEY_ID' not in os.environ:
         raise SkipTest("AWS keys not found")
 
-def get_crawler(settings_dict=None):
+def get_crawler(spidercls=None, settings_dict=None):
     """Return an unconfigured Crawler object. If settings_dict is given, it
     will be used to populate the crawler settings with a project level
     priority.
     """
-    from scrapy.crawler import Crawler
+    from scrapy.crawler import CrawlerRunner
     from scrapy.settings import Settings
+    from scrapy.spiders import Spider
 
-    return Crawler(Settings(settings_dict))
+    runner = CrawlerRunner(Settings(settings_dict))
+    return runner._create_crawler(spidercls or Spider)
 
 def get_pythonpath():
     """Return a PYTHONPATH suitable to use in processes so that they find this
@@ -44,28 +46,8 @@ def get_testenv():
     env['PYTHONPATH'] = get_pythonpath()
     return env
 
-def get_testlog():
-    """Get Scrapy log of current test, ignoring the rest"""
-    with open("test.log", "rb") as fp:
-        loglines = fp.readlines()
-
-    thistest = []
-    for line in loglines[::-1]:
-        thistest.append(line)
-        if "[-] -->" in line:
-            break
-    return "".join(thistest[::-1])
-
-
 def assert_samelines(testcase, text1, text2, msg=None):
     """Asserts text1 and text2 have the same lines, ignoring differences in
     line endings between platforms
     """
     testcase.assertEqual(text1.splitlines(), text2.splitlines(), msg)
-
-def docrawl(spider, settings=None):
-    """Configure and start Crawler; return the result of crawler.start()"""
-    crawler = get_crawler(settings)
-    crawler.configure()
-    crawler.crawl(spider)
-    return crawler.start()
