@@ -1,4 +1,5 @@
-import urlparse
+from __future__ import print_function
+from six.moves.urllib.parse import urljoin
 
 from twisted.internet import reactor
 from twisted.web import server, resource, static, util
@@ -6,14 +7,16 @@ from twisted.web import server, resource, static, util
 class SiteTest(object):
 
     def setUp(self):
+        super(SiteTest, self).setUp()
         self.site = reactor.listenTCP(0, test_site(), interface="127.0.0.1")
         self.baseurl = "http://localhost:%d/" % self.site.getHost().port
 
     def tearDown(self):
+        super(SiteTest, self).tearDown()
         self.site.stopListening()
 
     def url(self, path):
-        return urlparse.urljoin(self.baseurl, path)
+        return urljoin(self.baseurl, path)
 
 def test_site():
     r = resource.Resource()
@@ -27,5 +30,5 @@ def test_site():
 
 if __name__ == '__main__':
     port = reactor.listenTCP(0, test_site(), interface="127.0.0.1")
-    print "http://localhost:%d/" % port.getHost().port
+    print("http://localhost:%d/" % port.getHost().port)
     reactor.run()
